@@ -1,15 +1,14 @@
-#!/usr/bin/env python
-# vim:fileencoding=utf-8
+# -*- coding: utf-8 -*-
+
+from pybb import defaults
 
 __author__ = 'zeus'
 
-import defaults
 
 def processor(request):
     context = {}
     for i in (
         'PYBB_TEMPLATE',
-        'PYBB_BUTTONS',
         'PYBB_DEFAULT_AVATAR_URL',
         'PYBB_MARKUP',
         'PYBB_DEFAULT_TITLE',
